<?php
header("Content-Type: application/json");
include 'db_config.php';  // Assuming db_config.php contains the database connection function

$response = array();

// Connect to the database
$conn = dbConnect();  // Connect to the database

// Check the connection
if (!$conn) {
    $response['status'] = "error";
    $response['message'] = "Failed to connect to the database.";
    echo json_encode($response);
    exit;
}

// Retrieve the user ID from the URL query parameter
$uid = isset($_GET['uid']) ? $_GET['uid'] : null;

// Check if the user ID is provided
if ($uid === null) {
    $response['status'] = "error";
    $response['message'] = "User ID is required.";
    echo json_encode($response);
    exit;
}

// SQL query to fetch posts related to the user, including only image-related fields
$sql = "SELECT id, uid, image_url FROM posts WHERE uid = ? ORDER BY id DESC";

// Prepare and execute the SQL query
$stmt = mysqli_prepare($conn, $sql);

if ($stmt === false) {
    $response['status'] = "error";
    $response['message'] = "Error in preparing SQL statement.";
    echo json_encode($response);
    exit;
}

mysqli_stmt_bind_param($stmt, "s", $uid);
mysqli_stmt_execute($stmt);
$result = mysqli_stmt_get_result($stmt);

// Check if there are any posts found for this user
if (mysqli_num_rows($result) > 0) {
    $response['status'] = "success";
    $response['image'] = array();

    // Fetch the image details from the database result
    while ($row = mysqli_fetch_assoc($result)) {
        $post = array();
        $post['id'] = $row['id'];
        $post['uid'] = $row['uid'];
        $post['image_url'] = $row['image_url'];  // Only the image URL is included

        // Add each image to the response array
        array_push($response['image'], $post);
    }
} else {
    $response['status'] = "empty";
    $response['message'] = "No posts found for this user.";
}

// Return the JSON response
echo json_encode($response);

// Close the database connection
mysqli_close($conn);
?>